# The following has been generated automatically from src/gui/editorwidgets/core/qgseditorwidgetregistry.h
try:
    QgsEditorWidgetRegistry.__group__ = ['editorwidgets', 'core']
except (NameError, AttributeError):
    pass



# The following has been generated automatically from src/core/mesh/qgsmeshlayertemporalproperties.h
try:
    QgsMeshLayerTemporalProperties.__overridden_methods__ = ['writeXml', 'readXml', 'setDefaultsFromDataProviderTemporalCapabilities']
    QgsMeshLayerTemporalProperties.__group__ = ['mesh']
except (NameError, AttributeError):
    pass



# The following has been generated automatically from src/core/editform/qgsattributeeditortextelement.h
try:
    QgsAttributeEditorTextElement.__overridden_methods__ = ['clone']
    QgsAttributeEditorTextElement.__group__ = ['editform']
except (NameError, AttributeError):
    pass
